/*
--------------------------------------------------------------------------------
 Includefile for LawnMaker to produce some basic shapes of grassblades
 This file is always included with lawnmaker so don't include it a
 second time in your main file
--------------------------------------------------------------------------------

Contents:
Blade1, Blade 2, ... Blade5
  Tipped grassblades that are more and more curved to the ground with rising numbers.
  1 and 2 are simply a little curved
  3 has its tip point horizontaly
  4 and 5 are curved so that the tips point to the ground again

Blunt1, ... Blunt3
The same as Blade1 to 3 except, that in this case there is no tip, so that
the grassblade appears as if cut by a mower.
*/

// Macro to create pointed grassblades
//------------------------------------
#macro BladeMaker (kruemmung)
  parametric { function { u },
               function { 1-(u-1)*(u-1) },
               function { v*(kruemmung-u)/kruemmung }
               <0, -0.03>, <kruemmung, 0.03>
               contained_by { box { <0,0,-0.03>, <kruemmung, 1, 0.03> } }
               accuracy 0.005  precompute 15 x,y,z   
    finish { ambient 0.2  diffuse 0.5  brilliance 1.0  phong 0.1  phong_size 0.5 }
    normal { marble 1  scale <0.03,1,1> rotate <0,90,0> }
  }
#end

// Macro to create blunt grassblades (i.e. cut by a mower)
//------------------------------------
#macro BladeMaker2 (kruemmung)
  parametric { function { u },
               function { 1-(u-1)*(u-1) },
               function { v*(2*kruemmung-u)/kruemmung }
               <0, -0.03>, <kruemmung, 0.03>
               contained_by { box { <0,0,-0.03>, <kruemmung, 1, 0.03> } }
               accuracy 0.005  precompute 15 x,y,z   
   finish { ambient 0.2  diffuse 0.5  brilliance 1.0  phong 0.1  phong_size 0.5 }
   normal { marble 1  scale <0.03,1,1> rotate <0,90,0> }
  }
#end

/*
--------------------------------------------------------------------------------
 5 different grassblades, varying in curvation
--------------------------------------------------------------------------------
*/
#declare Blade1 = object { BladeMaker (0.5) scale <1,1.333,1> } 
#declare Blade2 = object { BladeMaker (0.7) scale <1,1.098,1> } 
#declare Blade3 = object { BladeMaker (1) }
#declare Blade4 = object { BladeMaker (1.2) }
#declare Blade5 = object { BladeMaker (1.5) } 

#declare Blunt1 = object { BladeMaker2 (0.5) scale <1,1.333,1> } 
#declare Blunt2 = object { BladeMaker2 (0.7) scale <1,1.098,1> } 
#declare Blunt3 = object { BladeMaker2 (1) }
