/*
--------------------------------------------------------------------------------
Examplefile to show usage of LawnMaker 1.1
This creates a simple round grasspatch with only a few longer straws in it
Test scene by TdeG (2020)
--------------------------------------------------------------------------------
*/

//+w640 +h450 +a0.3 +am2 +bm2 +bs8 +wt6

#version 3.8;

#include "lawnmaker.inc"
#include "Halm1.inc"

global_settings {
  assumed_gamma 1.0
  max_trace_level 5
  radiosity {
    pretrace_start 0.08
    pretrace_end   0.04
    count 50, 1000
    nearest_count 10, 5
    error_bound 1
    recursion_limit 2
    low_error_factor .3
    gray_threshold 0.0
    minimum_reuse 0.015
    maximum_reuse 0.1
    brightness 1

    adc_bailout 0.01/2
    normal off
    media off
    always_sample off
    //max_sample 1.0
  }
}

sphere {0, 1e4 pigment {rgb 0.5} finish {emission 1.0 diffuse 0.0}}

plane {y, 0.0 pigment {rgb 0.5}}

camera { 
  location  <0, 5, -7> 
  direction 1.5*z
  right     x*image_width/image_height
  angle     40
  look_at   <0.0, 0.5, 0.0>
}

light_source {
  <-30, 30, -30>            
  color rgb <0.98, 0.98, 0.97>*3 
}

light_source {
  <30, 30, 30>            
  color rgb <1, 1, 1>*0.1 
  shadowless
}

//======================================================================================
#local BoxScale = 4;
// Only the necessary values are changed
#declare LawnStart = <-0.5*BoxScale, -0.5*BoxScale>;
#declare LawnStop  = < 0.5*BoxScale,  0.5*BoxScale>;
#declare LawnStepX = <0.1, 0.1>;
#declare LawnStepZ = <0.1, 0.1>;
/*
To create a square patch, a boxed pattern is used. By setting the outer
regions to 0, there are no plants there and thus there is no square patch of
plants.
*/

#declare LawnHeight = 
pigment { 
  boxed 
  color_map { 
    [0.0, rgb 0.0] 
    [0.5, rgb 0.2] 
    [0.8, rgb 0.0] 
    [1.0, rgb 1.0] 
  } 
  scale BoxScale 
}

// New coloring used for the straws (or dead grass)
#declare LawnColor[4] =
pigment {
  spotted turbulence 2 scale 0.5
  colour_map {
    [1.0 color rgb <0.9, 0.8, 0.3>]
  }
}

#declare T = 6;
#declare TypeGeometry = array[T] { Blade1,     Blade2,      Blade3,    Blade4,    Blade5,    Halm1   }
#declare TypeWeight   = array[T] { 4,          4,           4,         3,         3,         0.4     }
#declare TypeSize1    = array[T] { <.7,.6,.7>, <.7,.5,.7>,  <.6,.4,.6>,<.6,.4,.6>,<.6,.4,.6>,<1,1,1> }
#declare TypeSize2    = array[T] { <1,1.5,1>,  <1,1.4,1>,   <1,1.2,1>, <1,1.1,1>, <1,1.1,1>, <3,3,3> }
#declare TypeColMap   = array[T] { 0,          1,           0,         2,         4,         4       }
#declare TypeTurn     = array[T] { <0, 360>,   <0, 360>,    <0, 360>,  <0, 360>,  <0, 360>,  <0, 360>}
#declare TypeIncline  = array[T] { <0, 50>,    <0, 30>,     <0, 10>,    <0,5>,    <-2,2>,    <-5,5>  }


// invoking LawnMaker and thus actually producing the grass
LawnMaker()

// the patch with transformations:
object {GrassPatch 
  //translate <-0.5, 0.0, 0.0>*BoxScale 
  //rotate 90*y
}

/*
difference {
  box {-0.50, 0.50}
  box {-0.49, 0.49}
  plane {y, 0 rotate 180*x translate 0.1*y}
  scale BoxScale
}
*/